# This file was auto-generated by Fern from our API Definition.

import typing

VersionEventTrigger = typing.Union[
    typing.Literal[
        "deploy", "container_register", "rollback", "hot_swap", "helm_failure", "redeploy", "cleanup", "manual"
    ],
    typing.Any,
]
