# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class OAuthTokenResponse(UniversalBaseModel):
    """
    Response for token exchange.
    """

    access_token: str = pydantic.Field()
    """
    WorkOS access token
    """

    expires_in: int = pydantic.Field()
    """
    Token expiration in seconds
    """

    refresh_token: typing.Optional[str] = pydantic.Field(default=None)
    """
    Refresh token (if available)
    """

    token_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    Token type
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
