# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class TimeSeriesPoint(UniversalBaseModel):
    """
    A single time series data point.
    """

    ts: dt.datetime = pydantic.Field()
    """
    Timestamp for the data point
    """

    value: float = pydantic.Field()
    """
    Metric value at timestamp
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
