# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .finish_reason import FinishReason
from .stream_metadata import StreamMetadata
from .stream_usage import StreamUsage


class FinishStepPart(UniversalBaseModel):
    """
    Marks the end of a step (API call).
    """

    finish_reason: typing_extensions.Annotated[FinishReason, FieldMetadata(alias="finishReason")] = pydantic.Field(
        alias="finishReason"
    )
    """
    Reason step finished
    """

    metadata: typing.Optional[StreamMetadata] = pydantic.Field(default=None)
    """
    Metadata including parentToolUseId for subagents
    """

    usage: StreamUsage = pydantic.Field()
    """
    Token usage for this step
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
