# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .otlp_log_record import OtlpLogRecord
from .otlp_scope import OtlpScope


class OtlpScopeLogs(UniversalBaseModel):
    """
    OTLP scope logs containing log records.
    """

    log_records: typing_extensions.Annotated[
        typing.Optional[typing.List[OtlpLogRecord]], FieldMetadata(alias="logRecords")
    ] = pydantic.Field(alias="logRecords", default=None)
    scope: typing.Optional[OtlpScope] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
