import terminaluse


def test_all_public_exports_resolve() -> None:
    unresolved: list[str] = []

    for name in terminaluse.__all__:
        try:
            getattr(terminaluse, name)
        except Exception as exc:  # pragma: no cover - failure path
            unresolved.append(f"{name}: {type(exc).__name__}: {exc}")

    assert not unresolved, "Unresolvable public exports:\n" + "\n".join(unresolved)
