# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ScheduleActionInfo(UniversalBaseModel):
    """
    Information about the scheduled action
    """

    task_queue: str = pydantic.Field()
    """
    Task queue for the workflow
    """

    workflow_id_prefix: str = pydantic.Field()
    """
    Prefix for workflow execution IDs
    """

    workflow_name: str = pydantic.Field()
    """
    Name of the workflow being executed
    """

    workflow_params: typing.Optional[typing.List[typing.Any]] = pydantic.Field(default=None)
    """
    Parameters passed to the workflow
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
