# This file was auto-generated by Fern from our API Definition.

import typing

VersionStatus = typing.Union[
    typing.Literal["DEPLOYING", "ACTIVE", "FAILED", "UNHEALTHY", "DRAINING", "RETIRED", "ROLLED_BACK"], typing.Any
]
