# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .stream_metadata import StreamMetadata


class StartStepPart(UniversalBaseModel):
    """
    Marks the start of a new step (API call).
    """

    metadata: typing.Optional[StreamMetadata] = pydantic.Field(default=None)
    """
    Metadata including parentToolUseId for subagents
    """

    request: typing.Optional[typing.Dict[str, typing.Any]] = pydantic.Field(default=None)
    """
    Request details for this step
    """

    warnings: typing.Optional[typing.List[typing.Any]] = pydantic.Field(default=None)
    """
    Warnings from this step
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
