# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ScheduleSpecInfo(UniversalBaseModel):
    """
    Information about the schedule specification
    """

    cron_expressions: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Cron expressions for the schedule
    """

    end_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    When the schedule stops being active
    """

    intervals_seconds: typing.Optional[typing.List[int]] = pydantic.Field(default=None)
    """
    Interval specifications in seconds
    """

    start_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    When the schedule starts being active
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
