# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .ui_message import UiMessage


class ListMessagesV2Response(UniversalBaseModel):
    """
    Response for list messages v2 endpoint.
    """

    data: typing.List[UiMessage] = pydantic.Field()
    """
    List of UIMessages
    """

    has_more: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="hasMore")] = pydantic.Field(
        alias="hasMore", default=None
    )
    """
    Whether there are more messages to fetch
    """

    next_cursor: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="nextCursor")] = pydantic.Field(
        alias="nextCursor", default=None
    )
    """
    Cursor for fetching the next page
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
