# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .project_collaborator_response import ProjectCollaboratorResponse


class ProjectCollaboratorsResponse(UniversalBaseModel):
    """
    Response model for project collaborators list.
    """

    can_manage: bool = pydantic.Field()
    """
    Whether the current user can manage collaborators.
    """

    collaborators: typing.Optional[typing.List[ProjectCollaboratorResponse]] = pydantic.Field(default=None)
    """
    Project collaborators with explicit direct roles.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
