# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .task_status import TaskStatus


class Task(UniversalBaseModel):
    created_at: typing.Optional[dt.datetime] = None
    created_version_id: typing.Optional[str] = None
    current_version_id: typing.Optional[str] = None
    filesystem_id: str
    id: str
    name: typing.Optional[str] = None
    namespace_id: str
    params: typing.Optional[typing.Dict[str, typing.Any]] = None
    status: typing.Optional[TaskStatus] = None
    status_reason: typing.Optional[str] = None
    task_metadata: typing.Optional[typing.Dict[str, typing.Any]] = None
    updated_at: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
