# This file was auto-generated by Fern from our API Definition.

import typing

ToolPartState = typing.Union[
    typing.Literal["input-streaming", "input-available", "output-available", "output-error"], typing.Any
]
