# Install terminaluse with observability extras
terminaluse[observability]
{% if sdk_type == "claude_agent_sdk" %}
claude-agent-sdk>=0.1.38,<0.2.0
{% elif sdk_type == "codex_agent_sdk" %}
openai-agents>=0.9.0,<1.0.0
{% endif %}
