# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SystemFolderTypeResponse(UniversalBaseModel):
    """
    Response model for a system folder type from the registry.
    """

    host_path: str = pydantic.Field()
    """
    Relative path from $DATA_ROOT/tasks/{task_id}/ on the host.
    """

    sandbox_mount_path: str = pydantic.Field()
    """
    Absolute path where this folder is mounted in the sandbox.
    """

    type: str = pydantic.Field()
    """
    The system folder type identifier (e.g., 'dot_claude').
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
