# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.data_part import DataPart
from ...types.text_part import TextPart

CreateTaskEventRequestContent = typing.Union[TextPart, DataPart]
