# This file was auto-generated by Fern from our API Definition.

import typing

TaskStatus = typing.Union[
    typing.Literal["IDLE", "CANCELED", "COMPLETED", "FAILED", "RUNNING", "TERMINATED", "TIMED_OUT", "DELETED"],
    typing.Any,
]
