# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class VersionMetricsResponse(UniversalBaseModel):
    """
    Response model for version deployment metrics.
    """

    deployment_duration_p95seconds: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="deployment_duration_p95_seconds")
    ] = pydantic.Field(alias="deployment_duration_p95_seconds", default=None)
    """
    P95 deployment duration in seconds for this version
    """

    deployment_duration_seconds: typing.Optional[int] = pydantic.Field(default=None)
    """
    Average deployment duration in seconds for this version
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
