# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class Usage(UniversalBaseModel):
    """
    Token usage statistics.
    """

    input_tokens: typing_extensions.Annotated[int, FieldMetadata(alias="inputTokens")] = pydantic.Field(
        alias="inputTokens"
    )
    """
    Input tokens used
    """

    output_tokens: typing_extensions.Annotated[int, FieldMetadata(alias="outputTokens")] = pydantic.Field(
        alias="outputTokens"
    )
    """
    Output tokens used
    """

    total_tokens: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="totalTokens")] = (
        pydantic.Field(alias="totalTokens", default=None)
    )
    """
    Total tokens (input + output)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
