from terminaluse.lib.sandbox.mounts import assemble_sandbox_mounts


def test_assemble_sandbox_mounts_includes_claude_and_codex_system_folders() -> None:
    mounts = assemble_sandbox_mounts(
        task_id="task_123",
        filesystem_id="fs_123",
        manifest=None,
        agent_workdir="/tmp",
        filesystem_host_path="/tmp/fs_123",
    )

    mount_by_target = {mount.sandbox_path: mount.host_path for mount in mounts}

    assert mount_by_target["/root/.claude"].endswith("/tasks/task_123/.claude")
    assert mount_by_target["/root/.codex"].endswith("/tasks/task_123/.codex")
