# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .search_result_type import SearchResultType


class SearchResultItem(UniversalBaseModel):
    """
    A single search result item.
    """

    id: str = pydantic.Field()
    """
    The unique identifier
    """

    name: str = pydantic.Field()
    """
    The display name
    """

    namespace_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The namespace this resource belongs to
    """

    status: typing.Optional[str] = pydantic.Field(default=None)
    """
    The current status
    """

    type: SearchResultType = pydantic.Field()
    """
    The type of resource
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
