# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .organization_invitation_response import OrganizationInvitationResponse


class CreateOrganizationInvitationResponse(UniversalBaseModel):
    """
    Response model for create invitation endpoint.
    """

    already_exists: typing.Optional[bool] = pydantic.Field(default=None)
    """
    True when a pending invite already exists for this email
    """

    invitation: OrganizationInvitationResponse

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
