# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class HandlerCompletePart(UniversalBaseModel):
    """
    Marks completion of event/send handler lifecycle for a specific event.
    """

    duration_ms: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="durationMs")] = pydantic.Field(
        alias="durationMs", default=None
    )
    """
    Handler runtime in milliseconds
    """

    error: typing.Optional[str] = pydantic.Field(default=None)
    """
    Handler error text when execution failed
    """

    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    """
    Event ID correlated to this handler completion
    """

    success: bool = pydantic.Field()
    """
    Whether handler execution succeeded
    """

    task_id: typing_extensions.Annotated[str, FieldMetadata(alias="taskId")] = pydantic.Field(alias="taskId")
    """
    Task ID whose handler lifecycle completed
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
