# This file was auto-generated by Fern from our API Definition.

import typing

FinishReason = typing.Union[
    typing.Literal["stop", "tool-calls", "length", "content-filter", "error", "other"], typing.Any
]
