# This file was auto-generated by Fern from our API Definition.

import typing

UpsertProjectCollaboratorRequestRole = typing.Union[
    typing.Literal["discoverer", "viewer", "editor", "owner"], typing.Any
]
